cmoncrawl.aggregator.index\_query.IndexAggregator.get\_number\_of\_pages
========================================================================

.. currentmodule:: cmoncrawl.aggregator.index_query

.. automethod:: IndexAggregator.get_number_of_pages